# fisher test python

## Getting Started

#### Installation

```
pip install fisher-test-python
```

#### Usage

```python
import nump as np
from fisher import fisher_test

ary = np.array([[1,2,3], [2,3,4]])
p_value = fisher_test(ary)

```

## Contact

* Jungwoo - jungwoo@linewalks.com